<?php

namespace App\Http\Controllers;

use App\Models\ActivityLog;
use App\Models\Permission;
use App\Models\User;
use App\Models\InitialTransaction;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;
use App\Http\Requests\BanksOrMobiles\{BanksOrMobilesStoreRequest, BanksOrMobilesUpdateRequest};
use App\Imports\BulkImport;
use App\Models\Payments;
use App\Models\ReceivePayments;
use App\Models\BanksOrMobiles;
use App\Models\BanksOrMobilesDetails;
use App\Models\Supplier;
use App\Models\Lender;
use App\Models\Banks;
use App\Models\Account;
use App\Models\Shop;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Datatables;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Maatwebsite\Excel\Facades\Excel;
use SimpleSoftwareIO\QrCode\Facades\QrCode;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;

use App\Exports\OrderAnalysisExport;


class BankOrMobileAccountsController extends Controller
{
    public function index()
    {

        $shop = Shop::where('id', Auth::user()->shop_id)->first();
        $banks_or_mobileCount = BanksOrMobiles::when(Auth::user()->role=='staff', function ($query){
                            $query->where('shop_id', Auth::user()->shop_id);
                        })
                        ->count();
        $prouctionUnits = Shop::all();

        return view('seller.bank-or-mobile-accounts.index', compact('shop', 'banks_or_mobileCount','prouctionUnits'));
    }



    public function data(Request $request)
    {
        
        if ($request->ajax()){
            
            if (isset($request->id) && $request->id != null) {
      
                $banks_or_mobile = BanksOrMobiles::findOrFail($request->id); 
                $accounts = Account::where('bank_or_mobile_wallet_id',$request->id)->get(); 
                
                $data = [
                    'prouctionUnits' =>Shop::all(),
                    'banks_or_mobile' => $banks_or_mobile,
                    'accounts' => $accounts,
                ];

                return view("seller.bank-or-mobile-accounts.modal-templates.edit", $data);
            }

            $product_name = $request->get('product_name', '');
            $unitId = $request->get('unitId', '');
            $statusId = $request->get('statusId', '-1');
        
           
            $start = $request->get('start', 0);
            $limit = $request->get('length', 10);
            if ($limit < 1 OR $limit > 100) {
                $limit = 100;
            }

            $search = isset($request->get('search')['value'])
                    ? $request->get('search')['value']
                    : null;

            $orderColumnList = [
                'name',
                'type',
            ];

            $orderColumnIndex = isset($request->get('order')[0]['column'])
                                ? $request->get('order')[0]['column']
                                : 0;
            $orderColumnDir = isset($request->get('order')[0]['dir'])
                                ? $request->get('order')[0]['dir']
                                : 'desc';
            $orderColumnDir = 'desc';

            $orderColumn = $orderColumnList[$orderColumnIndex] ?? 'product_id';

            $userRole = 'member';
            $userId = Auth::id();
            
            $data = BanksOrMobiles::searchTable($search)
                    ->with('accounts')
                    ->get()
                    ->groupBy('id')
                    ->map(function ($items) {
                        return [
                            'id' => $items->first()->id, // Assuming id is a column
                            'bank_name' => $items->first()->name, // Assuming bank_name is a column
                            'status' => $items->first()->status, // Assuming status is a column
                            'accounts' => $items->flatMap->accounts->pluck('account_no')->implode(', '),
                        ];
                    });
          
       
            
            $totalData = BanksOrMobiles::searchTable($search)
                        ->count();
            

            $table = Datatables::of($data)
            
           
                ->addColumn('id', function ($row) {    
                            
                    return $row['id'];
                })

                ->addColumn('banks_or_mobile_name', function ($row) {
                   return $row['bank_name'];
                })
    
                ->addColumn('accounts', function ($row) {
                    return $row['accounts'];
                })  

                ->addColumn('status', function ($row) {
                    if($row['status']==1){
                        return '
                        <div class="text-center">
                            <div class="text-xs inline-flex font-medium bg-green-500/20 text-green-700 rounded-full text-center px-2.5 py-1">Active</div>
                        </div>
                        ';
                    }

                    if($row['status']==0){
                        return '
                        <div class="text-center">
                            <div class="text-xs inline-flex font-medium bg-red-500/20 text-red-700 rounded-full text-center px-2.5 py-1">Deactive</div>
                        </div>
                        ';
                    }
                })  

                ->addColumn('actions', function ($row) {
                    $actionContent = '';
                    
                    $actionContent = '
                    <div class="w-full text-center">
                        <div class="flex flex-wrap items-center -m-1.5">
                                <div class="m-1.5">
                                    <button id="BtnStatusChange" data-id="'.$row['id'].'" class="btn bg-white dark:bg-gray-800 border-gray-200 dark:border-gray-700/60 hover:border-gray-300 dark:hover:border-gray-600">
                                        <svg class="fill-current text-violet-500 shrink-0" width="16" height="16" viewBox="0 0 16 16">
                                            <path d="M14.3 2.3L5 11.6 1.7 8.3c-.4-.4-1-.4-1.4 0-.4.4-.4 1 0 1.4l4 4c.2.2.4.3.7.3.3 0 .5-.1.7-.3l10-10c.4-.4.4-1 0-1.4-.4-.4-1-.4-1.4 0z"></path>
                                        </svg>
                                    </button>
                                </div>
                            <div class="m-1.5">
                                <!-- Start -->
                                <button id="BtnEditItem" data-id="'.$row['id'].'" class="btn bg-white dark:bg-gray-800 border-gray-200 dark:border-gray-700/60 hover:border-gray-300 dark:hover:border-gray-600">
                                    <svg class="fill-current text-gray-400 dark:text-gray-500 shrink-0" width="16" height="16" viewBox="0 0 16 16">
                                        <path d="M11.7.3c-.4-.4-1-.4-1.4 0l-10 10c-.2.2-.3.4-.3.7v4c0 .6.4 1 1 1h4c.3 0 .5-.1.7-.3l10-10c.4-.4.4-1 0-1.4l-4-4zM4.6 14H2v-2.6l6-6L10.6 8l-6 6zM12 6.6L9.4 4 11 2.4 13.6 5 12 6.6z"></path>
                                    </svg>
                                </button>
                                <!-- End -->
                            </div>
                            <div class="m-1.5">
                                <!-- Start -->
                                <button id="BtnDeleteItem" data-id="'.$row['id'].'" class="btn bg-white dark:bg-gray-800 border-gray-200 dark:border-gray-700/60 hover:border-gray-300 dark:hover:border-gray-600">
                                    <svg class="fill-current text-red-500 shrink-0" width="16" height="16" viewBox="0 0 16 16">
                                        <path d="M5 7h2v6H5V7zm4 0h2v6H9V7zm3-6v2h4v2h-1v10c0 .6-.4 1-1 1H2c-.6 0-1-.4-1-1V5H0V3h4V1c0-.6.4-1 1-1h6c.6 0 1 .4 1 1zM6 2v1h4V2H6zm7 3H3v9h10V5z"></path>
                                    </svg>
                                </button>
                                <!-- End -->
                            </div>
                        </div>                       
                    </div>
                    ';
                   
                    return $actionContent;
                })
                ->rawColumns(['id','banks_or_mobile_name','status','actions'])
                ->skipPaging()
                ->setTotalRecords($totalData)
                ->make(true);

            return $table;
        }
    }



    function loadInsertForm(Request $request){
        $data = [
            'prouctionUnits' =>Shop::all(),
        ];

   
        return view("seller.bank-or-mobile-accounts.modal-templates.create",$data);
    }

    /**
     * Store new banks_or_mobile
     *
     * @param BanksOrMobilesStoreRequest $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function insert(BanksOrMobilesStoreRequest $request)
    {
        
        try {
            if(Session::has('banks_or_mobile_date')){
                $banks_or_mobile = Session::forget('banks_or_mobile_date');
            }

            
            $banks_or_mobile = new BanksOrMobiles();
            $banks_or_mobile->name = $request->name ?? NULL;
            $banks_or_mobile->type = $request->type ?? 0;
            $banks_or_mobile->status = 1;
            $banks_or_mobile->save();
            $banks_or_mobileId = $banks_or_mobile->id; 
           
            if($request->account_no){
                foreach($request->account_no as $idx=>$account_no){      
                    if (!is_null($account_no)) {        
                        $account = new Account();
                        $account->holder_name = $request->holder_name[$idx] ?? '';
                        $account->address = $request->address[$idx] ?? '';
                        $account->opening_balance = $request->opening_balance[$idx] ?? 0;
                        $account->account_no = $account_no;
                        $account->bank_or_mobile_wallet_id = $banks_or_mobileId;
                        $account->save();
                    }
                }
            }

            return response()->json([
                'status' => 1,
                'message' => '<span class="flex space-x-4 text-green-600">Bank and Account created successfully</span>'
            ]);
            

        } catch (\Throwable $th) {
            report($th);

            return redirect()->back()
                    ->with('error', $th->getMessage())
                    ->withInput();
        }
    }

    /**
     * Update the banks_or_mobile data
     *
     * @param BanksOrMobilesUpdateRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function update(BanksOrMobilesUpdateRequest $request)
    {
        try {
            if(Session::has('banks_or_mobile_date')){
                Session::forget('banks_or_mobile_date');
            }
            
            $banks_or_mobile = BanksOrMobiles::find($request->id);   
            $banks_or_mobile->name = $request->name ?? NULL;
            $banks_or_mobile->type = $request->type ?? 0;
            $banks_or_mobile->save();
            $banks_or_mobileId = $banks_or_mobile->id; 
            
            
           
            if($banks_or_mobileId){

            $initialTransaction = Account::where('bank_or_mobile_wallet_id',$banks_or_mobileId)->delete();

            if($request->account_no){
                foreach($request->account_no as $idx=>$account_no){      
                    if (!is_null($account_no)) {        
                        $account = new Account();
                        $account->holder_name = $request->holder_name[$idx] ?? '';
                        $account->address = $request->address[$idx] ?? '';
                        $account->opening_balance = $request->opening_balance[$idx] ?? 0;
                        $account->account_no = $account_no;
                        $account->bank_or_mobile_wallet_id = $banks_or_mobileId;
                        $account->save();
                    }
                }
            }

                return response()->json([
                    'status' => 1,
                    'message' => '<span class="flex space-x-4 text-green-600">Data updated successfully</span>'
                ]);
            }
            else{
                return redirect()->back()->with('danger','Something happened wrong');
            }


        } catch (\Throwable $th) {
            report($th);
            return $this->apiResponse(500, "Something went wrong. {$th->getMessage()}");
        }
    }


    
    function loadDeleteForm(Request $request){

        $banks_or_mobile = BanksOrMobiles::findOrFail($request->id); 
        $accounts = Account::where('bank_or_mobile_wallet_id',$request->id)->get(); 


        abort_if(!$banks_or_mobile, 404);

        $data = [
            'banks_or_mobile' => $banks_or_mobile,           
            'accounts' => $accounts           
        ];

        return view('seller.bank-or-mobile-accounts.modal-templates.delete', $data);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Request $request){
        
        $validator = Validator::make($request->all(), [
            'id' => 'required'
        ]);

        //dd("farhad");
        
        $payments = Payments::where('bank_or_mobile_wallet_id',$request->id)->first();
        $receive_payments = ReceivePayments::where('bank_or_mobile_wallet_id',$request->id)->first();
       
        if($payments || $receive_payments){
            return response()->json([
                'status' => 0,
                'message' => '<span class="pt-5 px-5 flex space-x-4 text-red-500">This Name is already used for payment, You may deactivate only.'
            ]);
        }

        if ($validator->fails()) {
            return response()->json([
                'status' => 0,
                'message' => '<span class="pt-5 px-5 flex space-x-4 text-red-500">Field id is required</span>'
            ]);
        } else {

            if(session::has('banks_or_mobile_date')){
                session::forget('banks_or_mobile_date');
            }

            BanksOrMobiles::where('id', '=', $request->id)->delete();

            ActivityLog::updateProductActivityLog('Delete  BanksOrMobiles', $request->id);
                        
            return [
                'status' => 1,
                'message' => '<span class="pt-5 px-5 flex space-x-4 text-green-600">This Entry is deleted successfully.</span>'
            ];
        }
    }

        /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function bulkDelete(Request $request){
        
        $validator = Validator::make($request->all(), [
            'bulk_ids' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'status' => 0,
                'message' => '<span class="pt-5 px-5 flex space-x-4 text-red-500">Field id is required</span>'
            ]);
        } else {

            if(session::has('banks_or_mobile_date')){
                session::forget('banks_or_mobile_date');
            }
            $isBulkDelete = false;
            $arrBulkIds = explode(",",$request->bulk_ids);
            foreach($arrBulkIds as $id){
                BanksOrMobiles::where('id', '=', $id)->delete();
                $isBulkDelete = true;
            }

            
            if($isBulkDelete){
                ActivityLog::updateProductActivityLog('Bulk Delete  BanksOrMobiles',count($arrBulkIds));
            }
            
                        
            return [
                'status' => 1,
                'message' => '<span class="pt-5 px-5 flex space-x-4 text-green-600"> BanksOrMobiles deleted successfully.</span>'
            ];
        }
    }


    public function statusFormLoad(Request $request)
    {
        if ($request->ajax()){
            
            if (isset($request->id) && $request->id != null) {
      
                $banks_or_mobile = BanksOrMobiles::findOrFail($request->id); 
                
                $data = [
                    'banks_or_mobile' => $banks_or_mobile,
                ];

                return view("seller.bank-or-mobile-accounts.modal-templates.status", $data);
            }
        }
    }

        /**
     * Update the stock data
     *
     * @param BanksOrMobilesUpdateRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function updateStatus(Request $request)
    {
        try {
            if(Session::has('banks_or_mobile_date')){
                Session::forget('banks_or_mobile_date');
            }
            
            $banks_or_mobile = BanksOrMobiles::find($request->id);   

            $banks_or_mobile->status = $request->status ?? 0;
            $banks_or_mobile->save();
            $banks_or_mobileId = $banks_or_mobile->id; 
            
            if($banks_or_mobileId){
                return response()->json([
                    'status' => 1,
                    'message' => '<span class="flex space-x-4 text-green-600">BanksOrMobiles Status updated successfully</span>'
                ]);
            }
            else{
                return redirect()->back()->with('danger','Something happened wrong');
            }


        } catch (\Throwable $th) {
            report($th);
            return $this->apiResponse(500, "Something went wrong. {$th->getMessage()}");
        }
    }


    public function loadBanksOrMobilesByUnitID(Request $request){
        $data = [
            'banks_or_mobiles' => BanksOrMobiles::where('shop_id',$request->shop_id)->get(),
        ];
        return view('elements.load-banks_or_mobile-by-production-unit-id',$data);
    }

    

}