<x-app-layout>
    @section('title', 'Customers')

        <x-card title="Customers">
            <div class="mt-6">
                @if(session('success'))
                    <x-alert-success>{{ session('success') }}</x-alert-success>
                @endif
                @if(session('danger'))
                    <x-alert-danger>{{ session('danger') }}</x-alert-danger>
                @endif
                @if ($errors->any())
                    <x-alert-danger>
                        <ul class="mt-3 list-disc list-inside text-sm text-red-600">
                            @foreach ($errors->all() as $error)
                                <li>{{ $error }}</li>
                            @endforeach
                        </ul>
                    </x-alert-danger>
                @endif

                @if(in_array('add_customer', session('assignedPermissions')))
                    <x-button class="mb-6" color="green" id="BtnInsert">
                        <svg xmlns="http://www.w3.org/2000/svg" class="w-4 h-4" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 9v3m0 0v3m0-3h3m-3 0H9m12 0a9 9 0 11-18 0 9 9 0 0118 0z" />
                        </svg>
                        <span class="ml-2">
                        {{ __('translation.Add Customer') }}
                    </span>
                    </x-button>
                @endif
            </div>

            <div class="flex justify-between flex-col">
                <div class="overflow-x-auto">
                    <table class="w-full" id="datatable">
                        <thead>
                        <tr class="rounded-lg text-sm font-medium text-gray-700 text-left">
                            <th>{{ __('translation.ID') }}</th>
                            <th>{{ __('translation.Customer Name') }}</th>                          
                            <th>Father's/Husband's name</th>
                            <th>{{ __('translation.Contact Phone') }}</th>
                            <th>{{ __('translation.Dath Of Birth') }}</th>
                            <th>{{ __('translation.Action') }}</th>
                        </tr>
                        </thead>
                    </table>
                </div>
            </div>
        </x-card>


<!-- insert modal -->
    <x-modal.modal-full class="modal-hide modal-insert">
        <x-modal.header>
            <x-modal.title>
                {{ __('translation.Add Customer') }}
            </x-modal.title>
            <x-modal.close-button id="closeModalInsert" />
        </x-modal.header>
        <x-modal.body>
            <div class="pb-6">
                <form method="POST" action="{{ route('customer.store') }}" id="form-insert">
                    @csrf

                    <div class="grid grid-cols-3 sm:grid-cols-3 lg:grid-cols-3 gap-4 sm:gap-x-8 mb-4">
                        <div class="sm:col-span-3 grid grid-cols-3 sm:grid-cols-3 gap-4 sm:gap-x-8">
                            <div id="__customerNameWrapper">
                                <x-label for="customer_name">
                                    Customer's Name <x-form.required-mark/>
                                </x-label>
                                <x-input required type="text" name="customer_name" id="customer_name" class="bg-gray-200" />
                            </div>

                            <div id="__customerPhoneWrapper">
                                <x-label for="phone">
                                    {{ __('translation.phone') }} <x-form.required-mark/>
                                </x-label>
                                <x-input required type="text" name="contact_phone" id="contact_phone" class="bg-gray-200" />
                            </div>
                        </div>
                    </div>

                    <div class="mb-1 xl:mb-1">
                        <div class="flex flex-row items-center justify-between mb-2">
                            <h2 class="block whitespace-nowrap text-yellow-500 text-base font-bold">
                                Present Address
                            </h2>
                            <hr class="w-full ml-3 relative -top-1 border border-r-0 border-b-0 border-l-0 border-yellow-300">
                        </div>                        
                    </div>                        


                    <div class="sm:col-span-4 grid grid-cols-4 sm:grid-cols-4 gap-4 sm:gap-x-8 mb-4">
                        <div id="__customerDistrictWrapper">
                            <x-label for="district">
                                {{ __('translation.District Name') }} <x-form.required-mark/>
                            </x-label>
                            <select required style="width: 100%; margin-bottom: 15px;" id="district" class="form-control block font-medium w-full rounded-md shadow-sm border-gray-300 focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 mt-1 district" name="present_district">
                                <option></option>
                            </select>
                        </div>

                        <div id="__customerThanaWrapper">
                            <x-label for="thana">
                                {{ __('translation.Thana Name') }} <x-form.required-mark/>
                            </x-label>
                            <select required style="width: 100%; margin-bottom: 15px;" id="thana" class="form-control block font-medium w-full rounded-md shadow-sm border-gray-300 focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 mt-1 thana" name="present_thana">
                                <option></option>
                            </select>
                        </div>

                        <div id="__customerPostOfficeWrapper">
                            <x-label for="post_office">
                                {{ __('translation.Post Office Name') }} <x-form.required-mark/>
                            </x-label>
                            <select required style="width: 100%; margin-bottom: 15px;" id="post_office" class="form-control block font-medium w-full rounded-md shadow-sm border-gray-300 focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 mt-1 post_office" name="present_post_office">
                                <option></option>
                            </select>
                        </div>

                        <div id="__customerNameWrapper">
                            <x-label for="__customer_nameCreateOrder">
                                {{ __('translation.Postcode') }} <x-form.required-mark/>
                            </x-label>                                
                            <x-input type="text" name="present_post_code" id="post_code" class="bg-gray-200" />
                        </div>
                    </div>

                    <div class="grid grid-cols-1 sm:grid-cols-1 lg:grid-cols-1 gap-4 sm:gap-x-8 mb-4">
                        <div id="__customerStreetWrapper">
                            <x-label for="village_street">
                                {{ __('translation.Village/Street') }} <x-form.required-mark/>
                            </x-label>
                            <x-textarea name="present_village_street" id="village_street" class="bg-gray-200"></x-textarea>
                        </div>
                    </div>

                    <div class="mb-1 xl:mb-1">
                        <div class="flex flex-row items-center justify-between mb-2">
                            <h2 class="block whitespace-nowrap text-yellow-500 text-base font-bold">
                                Permanent Address
                            </h2>
                            <hr class="w-full ml-3 relative -top-1 border border-r-0 border-b-0 border-l-0 border-yellow-300">
                        </div>                        
                    </div>  
                    
                    <div class="mb-4">
                        <div class="flex flex-row gap-x-4">
                            <input type="checkbox" name="same_as_present" id="same_as_present" checked="true">
                            Same as present address                                            
                        </div>
                    </div>

                    <div class="permanent_address_wrapper">
                        <div class="sm:col-span-4 grid grid-cols-4 sm:grid-cols-4 gap-4 sm:gap-x-8 mb-4">
                            <div id="__customerDistrictWrapper">
                                <x-label for="district">
                                    {{ __('translation.District Name') }}
                                </x-label>
                                <select style="width: 100%; margin-bottom: 15px;" id="district2" class="form-control block font-medium w-full rounded-md shadow-sm border-gray-300 focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 mt-1 district" name="permanent_district">
                                    <option></option>
                                </select>
                            </div>

                            <div id="__customerThanaWrapper">
                                <x-label for="thana">
                                    {{ __('translation.Thana Name') }}
                                </x-label>
                                <select style="width: 100%; margin-bottom: 15px;" id="thana2" class="form-control block font-medium w-full rounded-md shadow-sm border-gray-300 focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 mt-1 thana" name="permanent_thana">
                                    <option></option>
                                </select>
                            </div>

                            <div id="__customerPostOfficeWrapper">
                                <x-label for="post_office">
                                    {{ __('translation.Post Office Name') }}
                                </x-label>
                                <select style="width: 100%; margin-bottom: 15px;" id="post_office2" class="form-control block font-medium w-full rounded-md shadow-sm border-gray-300 focus:border-indigo-300 focus:ring focus:ring-indigo-200 focus:ring-opacity-50 mt-1 post_office" name="permanent_post_office">
                                    <option></option>
                                </select>
                            </div>

                            <div id="__customerNameWrapper">
                                <x-label for="__customer_nameCreateOrder">
                                    {{ __('translation.Postcode') }}
                                </x-label>                                
                                <x-input type="text" name="permanent_post_code" id="post_code" class="bg-gray-200" />
                            </div>
                        </div>

                        <div class="grid grid-cols-1 sm:grid-cols-1 lg:grid-cols-1 gap-4 sm:gap-x-8 mb-4">
                            <div id="__customerStreetWrapper2">
                                <x-label for="village_street">
                                    {{ __('translation.Village/Street') }}
                                </x-label>
                                <x-textarea name="permanent_village_street" id="village_street" class="bg-gray-200"></x-textarea>
                            </div>
                        </div>
                    </div>

                    <div class="grid grid-cols-3 sm:grid-cols-3 lg:grid-cols-3 gap-4 sm:gap-x-8 mb-4">
                        <div class="sm:col-span-3 grid grid-cols-3 sm:grid-cols-3 gap-4 sm:gap-x-8">
                            <div id="__customerNameWrapper">
                                <x-label for="nationality">
                                    {{ __('translation.Nationality') }}
                                </x-label>
                                <x-input type="text" name="nationality" id="nationality" class="bg-gray-200" value="Bangladeshi" />
                            </div>

                            <div id="__customerNameWrapper">
                                <x-label for="sex">
                                    {{ __('translation.Sex') }} <x-form.required-mark/>
                                </x-label>
                                <div class="flex flex-row gap-x-4">
                                    <x-form.input-radio name="sex" id="male" value="male" checked="true">
                                        Male
                                    </x-form.input-radio>
                                
                                    <x-form.input-radio name="sex" id="female" value="female">
                                        Female
                                    </x-form.input-radio>
                                </div>
                            </div>
                        </div>
                    </div>
                
                            


                    <div class="flex justify-end py-6">
                        <x-button type="reset" color="gray" class="mr-1" id="cancelModalInsert">
                            {{ __('translation.Cancel') }}
                        </x-button>
                        <x-button type="submit" color="blue">
                            {{ __('translation.Submit') }}
                        </x-button>
                    </div>
                </form>
            </div>
        </x-modal.body>
    </x-modal.modal-full>

    {{-- update modal --}}
    <x-modal.modal-full class="modal-hide modal-update">
        <x-modal.header>
            <x-modal.title>
                {{ __('translation.Update Customer') }}
            </x-modal.title>
            <x-modal.close-button id="closeModalUpdate" />
        </x-modal.header>
        <x-modal.body>
            <div class="pb-6">
                <form method="POST" action="{{ route('customer.update') }}" id="form-update"></form>
            </div>
        </x-modal.body>
    </x-modal.modal-full>


    @push('bottom_js')
        <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
        
        <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery-validate/1.19.0/jquery.validate.js"></script>
        <script>

            $(document).ready(function() {
                
                $('.district').select2({
                    placeholder: "Select A District Name"
                });
                $('.thana').select2({
                    placeholder: "Select A Thana Name"
                });
                $('.post_office').select2({
                    placeholder: "Select A Post Office Name"
                });
            });
      </script>

<script>
        $(document).ready(function() {
            // Load District 
            $.ajax({
                url: '/districts/',
                type: 'GET',
                dataType: 'json',
                success: function(data) {
                    console.log(data);
                    $('.district').empty();
                    $('.district').append('<option value="">Select District</option>');
                    $.each(data, function(key, value) {
                        $('.district').append('<option value="' + value.district + '">' + value.district + '</option>');
                    });
                }
            });

            // Fetch postal codes based on selected district
            $('.district').change(function() {
                var districtName = $(this).val();
                var current = $(this);
                if(districtName) {
                    $.ajax({
                        url: '/thana/' + districtName,
                        type: 'GET',
                        dataType: 'json',
                        success: function(data) {
                            console.log(data);
                            current.parent().next().find('select').empty();
                            current.parent().next().find('select').append('<option value="">Select Thana</option>');
                            $.each(data, function(key, value) {
                                current.parent().next().find('select').append('<option value="' + value.thana + '">' + value.thana + '</option>');
                            });
                        }
                    });
                } else {
                    current.parent().next().find('select').empty();
                    current.parent().next().find('select').append('<option value="">Select Thana</option>');
                }
            });
            
            // Fetch postal codes based on selected district
            $('.thana').change(function() {
                var thanaName = $(this).val();
                var current = $(this);
                if(thanaName) {
                    $.ajax({
                        url: '/post-offices/' + thanaName,
                        type: 'GET',
                        dataType: 'json',
                        success: function(data) {
                            console.log(data);
                            current.parent().next().find('select').empty();
                            current.parent().next().find('select').append('<option value="">Select Post Office</option>');
                            $.each(data, function(key, value) {
                                current.parent().next().find('select').append('<option value="' + value.postoffice + '">' + value.postoffice + '</option>');
                            });
                        }
                    });
                } else {
                    current.parent().next().find('select').empty();
                    current.parent().next().find('select').append('<option value="">Select Postal office</option>');
                }
            });
            
            // Fetch postal codes based on selected district
            $('.post_office').change(function() {
                var post_office = $(this).val();
                var current = $(this);
                if(post_office) {
                    $.ajax({
                        url: '/postal-code/' + post_office,
                        type: 'GET',
                        dataType: 'json',
                        success: function(data) {
                            console.log(data);
                            current.parent().next().find('select').empty();
                            current.parent().next().find('input').val(data.postcode);                            
                        }
                    });
                } else {
                    current.parent().next().find('input').empty();                    
                }
            });
        });

        jQuery(".permanent_address_wrapper").addClass('hide');
        jQuery(document).on('change','#same_as_present',function () {   
            jQuery(".permanent_address_wrapper").toggleClass('hide');
        });
        
    </script>

      <script>
            $(document).ready(function() {
                

                dataTables("{{ route('customer.data') }}?date=" + $(this).val());

                var datatable;
                $('#inputDate').change(function() {
                    datatable.destroy();
                    dataTables("{{ route('customer.data') }}?date=" + $(this).val());
                });

                function dataTables(url) {
                    // Datatable
                    datatable = $('#datatable').DataTable({
                        processing: true,
                        serverSide: true,
                        ajax: url,
                        columns: [
                            {
                                name: 'id',
                                data: 'id',
                                render: function (data, type, row, meta) {
                                    return meta.row + meta.settings._iDisplayStart + 1
                                }
                            },
                            {
                                name: 'customer_name',
                                data: 'customer_name'
                            },
                            {
                                name: 'contact_phone',
                                data: 'contact_phone'
                            },
                            {
                                name: 'total_orders',
                                data: 'total_orders'
                            },
                            {
                                name: 'dob',
                                data: 'dob'
                            },
                            {
                                name: 'action',
                                data: 'action'
                            }
                        ],
                        columnDefs: [
                            {
                                targets: 0,
                                searchable: false,
                                orderable: false
                            }
                        ]
                    });
                }

                $('#BtnInsert').click(function() {
                    $('.modal-insert').removeClass('modal-hide');
                });

                $(document).on('click', '#closeModalUpdate', function() {
                    $('.modal-update').addClass('modal-hide');
                });

                $(document).on('click', '#BtnUpdate', function() {
                    $('.modal-update').removeClass('modal-hide');
                    $.ajax({
                        url: '{{ route('customer.data') }}?id=' + $(this).data('id'),
                        beforeSend: function() {
                            $('#form-update').html('Loading');
                        }
                    }).done(function(result) {
                        $('#form-update').html(result);
                    });
                });

                $('#closeModalInsert').click(function() {
                    $('.modal-insert').addClass('modal-hide');
                });

                $('#cancelModalInsert').click(function() {
                    $('.modal-insert').addClass('modal-hide');
                });

                $(document).on('click', '#BtnDelete', function() {
                    let drop = confirm('Are you sure?');
                    if (drop) {
                        $.ajax({
                            url: '{{ route('customer.delete') }}',
                            type: 'post',
                            data: {
                                'id': $(this).data('id'),
                                '_token': $('meta[name=csrf-token]').attr('content')
                            },
                            beforeSend: function() {
                                // Pesan yang muncul ketika memproses delete
                            }
                        }).done(function(result) {
                            if (result.status === 1) {
                                // Pesan jika data berhasil di hapus
                                alert('Data deleted successfully');
                                $('#datatable').DataTable().ajax.reload();
                            } else {
                                alert(result.message);
                            }
                        });
                    }
                });
            });

        </script>
    @endpush

</x-app-layout>
